## intent:greet
- Guten Morgen!
- Gute Nacht.
- guten Abend

## intent:farewell
- Danke, bis bald.
- Nein, auf Wiedersehen!
- tschüss

## intent:affirm
- Ja
- Recht
- das ist richtig

## intent:deny
- Nein Danke
- Nein

## intent:stop
- halt
- du kannst mir nicht helfen

## intent:thank
- Dankeschön
- Vielen Dank
- Danke dir

## intent:name
- ich bin [Tom](name)
- mein Name ist [John](name)

## intent: tech
- Shenzhen ist das Silicon Valley für Hardware-Firmen
- Die ganze Stadt ist ein Startup

## intent: about_date
- Morgen mittag
- Am letzten Sonntag

## intent: time_indicator
- nach [ein](num_hours:1) Stunde
- der [Hochzeit](event) für [Juni](num_month:6)

## intent: context_indicator
- in dies Punkt

## intent: using
- der Nutzung der [Seite](thing)

